## update: test.rb
x = { 1 => 2 }
x.map do |k, v|
end

# TODO: support showing type parameters

## hover: test.rb:2:3
Hash[Integer, Integer]#map : -> Array[...] | -> Enumerator[...]
